# 👾 bluer-agent

👾 `@agent` is a set of tools for interacting with LLMs.

## installation

```bash
pip install bluer-agent
```

## features

- [assistant](./bluer_agent/docs/assistant)
- [audio](./bluer_agent/docs/audio.md)
- [chat](./bluer_agent/docs/chat)
- [crawl](./bluer_agent/docs/crawl)
- [rag](./bluer_agent/docs/rag)
- [transcription](./bluer_agent/docs/transcription)
- [voice](./bluer_agent/docs/voice)

# aliases

[@assistant](./bluer_agent/docs/aliases/assistant.md) 
[@audio](./bluer_agent/docs/aliases/audio.md) 
[@chat](./bluer_agent/docs/aliases/chat.md) 
[@crawl](./bluer_agent/docs/aliases/crawl.md) 
[@rag](./bluer_agent/docs/aliases/rag.md) 
[@transcribe](./bluer_agent/docs/aliases/transcribe.md) 
[@voice](./bluer_agent/docs/aliases/voice.md) 

---


[![pylint](https://github.com/kamangir/bluer-agent/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-agent/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-agent/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-agent/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-agent/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-agent/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer-agent.svg)](https://pypi.org/project/bluer-agent/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer-agent)](https://pypistats.org/packages/bluer-agent)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 👾 [`bluer_agent-5.448.1`](https://github.com/kamangir/bluer-agent).
